%define oname ufdbGuard

Summary:        ufdbGuard is a URL filter for Squid
Name:           ufdbguard
Version:        1.35.8
Release:        %mkrel 1
License:        GPLv2
Group:          System/Servers
URL:            https://www.urlfilterdb.com/
Source0:        https://downloads.sourceforge.net/ufdbguard/%{oname}-%{version}.tar.gz
Source1:        https://www.urlfilterdb.com/files/downloads/ReferenceManual.pdf
Patch0:         ufdbGuard-1.35.7-fix-make_install.patch
Patch2:         ufdbGuard-1.35.7-do-not-phone-home.patch
Patch3:         ufdbGuard-1.33-listen-locally.patch
Patch4:         ufdbGuard-1.35.4-categories.patch
BuildRequires:  perl
BuildRequires:  wget
BuildRequires:  gdb
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  squid
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  systemd

Requires:       wget
Requires:       squid
Requires:       rootcerts

Requires(post):   rpm-helper
Requires(postun): rpm-helper
Requires(pre):    rpm-helper
Requires(preun):  rpm-helper

Obsoletes:      squidguard < 1.4-22

%description
ufdbGuard is a free URL filter for Squid with additional features like
SafeSearch enforcement for a large number of search engines, safer HTTPS 
visits and dynamic detection of proxies (URL filter circumventors).

ufdbGuard supports free and commercial URL databases that can be
downloaded from various sites and vendors.
You can even make your own URL database for ufdbGuard.

%package cgi
Summary:        Perl-based CGI for generating responses to blocked requests
Group:          System/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       webserver-base

%description cgi
This is the Perl-based CGI for ufdbGuard to generate responses to requests
that are blocked by the filtering software.  This can used with a web server
that supports CGIs as an alternative to the one built in to ufdbhttpd.


%prep
%setup -q -n %{oname}-%{version}
%patch -P 0 -p1
%patch -P 2 -p1
%patch -P 3 -p0
#patch -P 4 -p1

perl -pi -e 's|$root = .*;|$root = %{_datadir}/%{oname};|g' samples/URLblocked.cgi

# use local redirector instead of external one
perl -pi -e 's|cgibin.urlfilterdb.com|localhost:8080|g' src/ufdbGuard.conf.in
# default HTTPS redirections to localhost:443 instead of upstream site
# this can be overridden at runtime with the redirect-https configuration parameter
# e.g., redirect-https blockedhttps.urlfilterdb.com:443, in ufdbGuard.conf
perl -pi -e 's|blockedhttps.urlfilterdb.com|localhost|g' src/ufdb.h.in

cp %{SOURCE1} .

# ufdbGuard handles log rotation internally, a logrotate config is not needed.
# if you can disable internal rotation, perhaps we should add one.

%build
install -d %{buildroot}%{_sysconfdir}/sysconfig # needed by configure

%configure \
        --with-ufdb-bindir=%{_bindir} \
        --with-ufdb-piddir=%{_rundir}/ufdb \
        --with-ufdb-mandir=%{_mandir} \
        --with-ufdb-samplesdir=%{_datadir}/%{oname}/samples \
        --with-ufdb-config=%{_sysconfdir}/ufdb \
        --with-ufdb-logdir=%{_logdir}/ufdb \
        --with-ufdb-dbhome=%{_datadir}/%{oname}/db \
        --with-ufdb-imagesdir=%{_datadir}/%{oname}/images \
        --with-ufdb-user=squid
%make_build

%install
install -d %{buildroot}%{_logdir}/ufdb
install -d %{buildroot}%{_sysconfdir}/ufdb
install -d %{buildroot}%{_datadir}/%{oname}/db
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_var}/www/cgi-bin

%make_install logdir=%{_logdir}/ufdb cfgdir=%{_sysconfdir}/ufdb dbhome=%{_datadir}/%{oname}/db images_dir=%{_datadir}/%{oname}/images

install -m 0644 src/mtserver/ufdbguard.service %{buildroot}%{_unitdir}/ufdb.service
cp -a src/mtserver/sysconfig.ufdbguard %{buildroot}%{_sysconfdir}/sysconfig/%{name}
cp -a samples/URLblocked.cgi %{buildroot}%{_var}/www/cgi-bin/URLblocked.cgi

touch %{buildroot}%{_logdir}/ufdb/{ufdbguardd,ufdbgclient,ufdbhttpd,ufdbsignal}.log

cp -a test/blacklist/{entertainment,ipv6,known,proxies,security} %{buildroot}%{_datadir}/%{oname}/db/
rm -f %{buildroot}%{_datadir}/%{oname}/db/security/cacerts
ln -s /etc/pki/tls/certs/ca-bundle.crt %{buildroot}%{_datadir}/%{oname}/db/security/cacerts

# what are the other files in test/blacklist/ for?  installing in samples...
for file in domains emptyuserlist erruserlist expression-error expressions httpsgoogle.expressions httpsipblock.expressions license-status privuserlist urls; do
  cp -a test/blacklist/$file %{buildroot}%{_datadir}/%{oname}/samples/
done

cat > README.urpmi <<EOF
To enable ufdbGuard usage in Squid, you should add the following lines
to %{_sysconfdir}/squid/squid.conf:
url_rewrite_program %{_bindir}/ufdbgclient -l %{_logdir}/ufdb
url_rewrite_children 64
EOF

mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<EOF
d /run/ufdb 0700 squid squid -
EOF

install -d -m 0755 %{buildroot}%{_rundir}/ufdb

%postun
if [ "$1" = "0" ]; then
   rm -rf %{_datadir}/%{oname}
fi

%post
%_tmpfilescreate %{name}
%_post_service ufdb
systemctl -q try-restart squid.service ||:

%preun
%_preun_service ufdb

if [ "$1" = "0" ]; then
   rm -f %{_logdir}/ufdb/*
fi

%files
%doc CREDITS README.urpmi doc/README ReferenceManual.pdf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sysconfdir}/ufdb
%config(noreplace) %{_sysconfdir}/ufdb/%{oname}.conf
%{_bindir}/ufdbAnalyse
%{_bindir}/ufdbDLstatus
%{_bindir}/ufdb_analyse_urls
%{_bindir}/ufdb_analyse_users
%{_bindir}/ufdbConvertDB
%{_bindir}/ufdbgclient
%{_bindir}/ufdbGenTable
%{_bindir}/ufdbguardd
%{_bindir}/ufdbhttpd
%{_bindir}/ufdb-pstack
%attr(4755,squid,squid) %{_bindir}/ufdbsignal
%{_bindir}/ufdb_top_urls
%{_bindir}/ufdb_top_users
%{_bindir}/ufdbUpdate
%dir %{_datadir}/%{oname}
%dir %{_datadir}/%{oname}/db
%{_datadir}/%{oname}/db/*
%dir %{_datadir}/%{oname}/samples
%{_datadir}/%{oname}/samples/*
%dir %{_datadir}/%{oname}/images
%{_datadir}/%{oname}/images/*
%attr(-,squid,squid) %dir %{_logdir}/ufdb
%attr(0640,squid,squid) %{_logdir}/ufdb/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/ufdb.service
%dir %ghost %attr(0700, squid, squid) %{_rundir}/ufdb
%ghost %attr(0660, -, -) %{_rundir}/ufdb/ufdb.pid

%files cgi
%attr(0755,apache,apache) %{_var}/www/cgi-bin/URLblocked.cgi


%changelog
* Tue Jun 04 2024 daviddavid <daviddavid> 1.35.8-1.mga10
+ Revision: 2069627
- new version: 1.35.8

* Thu Apr 18 2024 daviddavid <daviddavid> 1.35.7-1.mga10
+ Revision: 2058448
- new version: 1.35.7
- switch to systemd unit from initscripts

* Thu Feb 16 2023 luigiwalser <luigiwalser> 1.35.5-1.mga9
+ Revision: 1943540
- 1.35.5

* Wed Jan 18 2023 luigiwalser <luigiwalser> 1.35.4-1.mga9
+ Revision: 1934176
- 1.35.4
- rediff patch 4

* Wed Mar 30 2022 umeabot <umeabot> 1.35.3-3.mga9
+ Revision: 1834224
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 1.35.3-2.mga9
+ Revision: 1747734
- rebuild for openssl 3.0.0

* Wed Nov 11 2020 luigiwalser <luigiwalser> 1.35.3-1.mga8
+ Revision: 1644744
- 1.35.3

* Fri Oct 16 2020 luigiwalser <luigiwalser> 1.35.1-1.mga8
+ Revision: 1636430
- 1.35.1
- push fixed build

* Sat Feb 15 2020 umeabot <umeabot> 1.34.2-2.mga8
+ Revision: 1523958
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Mar 17 2019 daviddavid <daviddavid> 1.34.2-1.mga7
+ Revision: 1378198
- new version: 1.34.2
- now openssl 1.1 supported
- update ReferenceManual.pdf for 1.34
- remove merged upstream squid-version patch
- rediff fix-make_install and categories patches

* Sun Sep 23 2018 umeabot <umeabot> 1.33.4-3.mga7
+ Revision: 1301500
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 wally <wally> 1.33.4-2.mga7
+ Revision: 1242866
- fix build on aarch64

* Fri Nov 10 2017 luigiwalser <luigiwalser> 1.33.4-1.mga7
+ Revision: 1176826
- build against openssl 1.0
- 1.33.4
- remove upstreamed patch 5
- rediff all of the remaining patches
- webmin module has been dropped
- update ReferenceManual.pdf

* Thu Mar 03 2016 umeabot <umeabot> 1.31-11.mga6
+ Revision: 984689
- Rebuild for openssl

* Wed Feb 17 2016 umeabot <umeabot> 1.31-10.mga6
+ Revision: 963156
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 luigiwalser <luigiwalser> 1.31-9.mga6
+ Revision: 887906
- update to 1.31-patch14

* Fri Sep 18 2015 luigiwalser <luigiwalser> 1.31-8.mga6
+ Revision: 880330
- try restarting squid after updating this package
- update ReferenceManual.pdf
- obsolete squidguard (incompatible with squid 3.4+)

* Thu Sep 10 2015 luigiwalser <luigiwalser> 1.31-6.mga6
+ Revision: 875633
- update to 1.31-patch13 (compatible with squid 3.4+)
- rediff listen-locally patch
- add patch to set squid-version

* Wed Oct 15 2014 umeabot <umeabot> 1.31-5.mga5
+ Revision: 744490
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.31-4.mga5
+ Revision: 690020
- Mageia 5 Mass Rebuild

* Mon Dec 02 2013 luigiwalser <luigiwalser> 1.31-3.mga4
+ Revision: 554677
- include reload in init script usage statement so that systemctl sees it

* Sat Oct 19 2013 umeabot <umeabot> 1.31-2.mga4
+ Revision: 528898
- Mageia 4 Mass Rebuild

* Sat Jun 29 2013 luigiwalser <luigiwalser> 1.31-1.mga4
+ Revision: 448181
- 1.31
- update ReferenceManual.pdf
- rediff patch 0 and patch 4
- redirect blocked https sites to localhost
- update files list
- add tmpfiles configuration for /var/run/ufdb

* Thu Jan 24 2013 luigiwalser <luigiwalser> 1.30-1.mga3
+ Revision: 392187
- 1.30
- remove upstreamed LSB headers patch

* Mon Jan 14 2013 umeabot <umeabot> 1.29-2.mga3
+ Revision: 384984
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 24 2012 luigiwalser <luigiwalser> 1.29-1.mga3
+ Revision: 309635
- imported package ufdbguard

